@@ -106,38 +106,27 @@ def reduce_depgraph(dg):
 
 # guarded imports, which don't need to be included in python-minimal
 excluded_imports = {
-    'argparse': set(('difflib', 'gettext', 'shutil')),
+    'argparse': set(('difflib', 'gettext')),
     'codecs': set(('encodings',)),
-    'collections': set(('cPickle', 'pickle', 'doctest')),
     'compileall': set(('concurrent', 'multiprocessing')),
-    'copy': set(('reprlib',)),
+    # We have _datetime, so _pydatetime import isn't reached
     'datetime': set(('_pydatetime',)),
-    #'functools': set(('_dummy_thread',)),
-    'hashlib': set(('logging', '_hashlib')),
-    #'hashlib': set(('_hashlib', '_md5', '_sha', '_sha256','_sha512',)),
     'heapq': set(('doctest',)),
-    'importlib': set(('csv', 'email', 'zipfile')),
-    #'io': set(('_dummy_thread',)),
+    'importlib': set(('csv',)),
     'logging': set(('multiprocessing',)),
-    'os': set(('nt', 'ntpath', 'os2', 'os2emxpath', 'mac', 'macpath',
-               'riscos', 'riscospath', 'riscosenviron')),
+    'os': set(('nt', 'ntpath')),
     'optparse': set(('gettext',)),
     'pathlib': set(('ntpath', 'urllib',)), # Windows only
-    'pickle': set(('argparse', 'doctest', 'pprint')),
-    'platform': set(('_ios_support', 'ctypes', 'plistlib', 'tempfile')),
-    'reprlib': set(('_dummy_thread',)),
-    'shutil': set(('bz2','lzma', 'tarfile', 'zipfile')),
-    #'socket': set(('_ssl',)),
-    '_sitebuiltins': set(('pydoc',)),
+    'pickle': set(('pprint',)),
+    'platform': set(('_ios_support', 'ctypes', 'plistlib')),
+    'shutil': set(('bz2', 'lzma', 'nt', 'tarfile', '_winapi')),
+    '_sitebuiltins': set(('_pyrepl', 'pydoc')),
     'subprocess': set(('dummy_threading',)),
-    'sysconfig': set(('pprint','_osx_support', '_aix_support')),
-    'tempfile': set(('_dummy_thread', 'shutil')),
-    'tokenize': set(('_tokenize',)),
+    'sysconfig': set(('_osx_support', '_aix_support')),
     'traceback': set(('_suggestions', 'codeop')),
-    'functools': set(('typing',)),
-    'zipfile': set(('bz2','lzma')),
+    'zipfile': set(('bz2', 'lzma')),
     'random': set(('statistics',)),
-    }
+}
 
 def main(argv):
     # Parse command line
